SparseTensorError

Enum SparseTensorError 

pub enum SparseTensorError {
Show 18 variants InvalidIndicesRank { expected: usize, actual: usize, }, InvalidIndicesDType { actual: DType, }, DeviceMismatch { expected: Device, actual: Device, }, SparseDimMismatch { indices_sparse_dim: usize, expected: usize, }, NnzMismatch { indices_nnz: usize, values_nnz: usize, }, InvalidValuesShape { expected: Vec<usize>, actual: Vec<usize>, }, IndexOutOfBounds { dim: usize, index: i64, size: usize, }, NegativeIndex { dim: usize, index: i64, }, InvalidCrowIndicesLen { expected: usize, actual: usize, }, InvalidColIndicesLen { expected: usize, actual: usize, }, NonMonotonicCrowIndices { row: usize, prev: i64, curr: i64, }, InvalidCrowIndexValue { index: usize, value: i64, }, ColIndexOutOfBounds { index: i64, ncols: usize, }, DuplicateCsrColumn { row: usize, col: i64, }, DuplicateCooIndex { position: usize, coord: Vec<i64>, }, UnsortedCooIndex { position: usize, previous: Vec<i64>, current: Vec<i64>, }, DenseTensor(DenseTensorError), UnsupportedRank { rank: usize, },
}
Error type for sparse tensor operations.

Variants



InvalidIndicesRank

Indices tensor has wrong rank (expected 2 for COO).

Fields

expected: usize
actual: usize


InvalidIndicesDType

Indices tensor has wrong dtype (must be I64).

Fields

actual: DType


DeviceMismatch

Indices tensor is on a different device than values.

Fields

expected: Device
actual: Device


SparseDimMismatch

Indices sparse_dim doesn’t match the dense shape.

Fields

indices_sparse_dim: usize
expected: usize


NnzMismatch

Number of non-zero entries doesn’t match between indices and values.

Fields

indices_nnz: usize
values_nnz: usize


InvalidValuesShape

Values tensor shape doesn’t match expected [nnz, *dense_dims].

Fields

expected: Vec<usize>
actual: Vec<usize>


IndexOutOfBounds

Index out of bounds for the dense shape.

Fields

dim: usize
index: i64
size: usize


NegativeIndex

Negative index in indices tensor.

Fields

dim: usize
index: i64


InvalidCrowIndicesLen

CSR crow_indices has wrong length (expected nrows + 1).

Fields

expected: usize
actual: usize


InvalidColIndicesLen

CSR col_indices has wrong length (expected nnz).

Fields

expected: usize
actual: usize


NonMonotonicCrowIndices

CSR crow_indices values are not monotonically increasing.

Fields

row: usize
prev: i64
curr: i64


InvalidCrowIndexValue

CSR crow_indices contains an invalid value.

Fields

index: usize
value: i64


ColIndexOutOfBounds

CSR column index out of bounds.

Fields

index: i64
ncols: usize


DuplicateCsrColumn

CSR row contains the same column index more than once.

Fields

row: usize
col: i64


DuplicateCooIndex

A coalesced COO tensor contains duplicate coordinates.

Fields

position: usize
coord: Vec<i64>


UnsortedCooIndex

A coalesced COO tensor contains coordinates out of lexicographic order.

Fields

position: usize
previous: Vec<i64>
current: Vec<i64>


DenseTensor(DenseTensorError)

Dense tensor error during conversion.



UnsupportedRank

Only 2D sparse CSR tensors are supported.

Fields

rank: usize